@@ -1,7 +1,8 @@
-from .context_provider import context_provider
+from .context_provider import context_provider, context_provider_with_permissions
 from .authentication_middleware import authentication_middleware
 from .with_authentication import with_authentication
 
 __all__ = ('context_provider',
            'authentication_middleware',
-           'with_authentication')
+           'with_authentication',
+           'context_provider_with_permissions')
